@@ -1,5 +1,5 @@
 from concurrency.tests.all import *
-from concurrency.tests.contrib_admin import TestDjangoAdmin
+from concurrency.tests.contrib_admin import *
 from concurrency.tests.forms import *
 from concurrency.tests.middleware import *
 from concurrency.tests.conf import *
